/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.storagemanager.automatic;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.DialogFragment;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.os.Bundle;
import com.android.storagemanager.R;

/**
 * Fragment to warn the user about activating the storage manager.
 */
public class WarningDialogFragment extends DialogFragment implements OnClickListener {
    public static final String TAG = "WarningDialogFragment";

    /**
     * Returns a new instance of the WarningDialogFragment.
     */
    public static WarningDialogFragment newInstance() {
        return new WarningDialogFragment();
    }

    @Override
    public Dialog onCreateDialog(Bundle savedInstanceState) {
        return new AlertDialog.Builder(getActivity())
                .setMessage(R.string.automatic_storage_manager_activation_warning)
                .setNegativeButton(android.R.string.ok, (OnClickListener) this)
                .create();
    }

    @Override
    public void onClick(DialogInterface dialog, int which) {
        finishActivity();
    }

    @Override
    public void onCancel(DialogInterface dialog) {
        finishActivity();
    }

    private void finishActivity() {
        Activity activity = getActivity();
        if (activity != null) {
            activity.finish();
        }
    }
}